
#import "MString.h"

@implementation DAYString (MString)

- clear
{
	[self freeString];
	return self;
}

- ( const char* ) string
{
   return [self stringValue];
}

- setString: ( const char *) aString
{
	[self setStringValue:aString];
	return self;
}

- replaceChar: ( char ) aChar withChar: ( char ) replaceChar
{
	char abuf[2];
	char rbuf[2];
	abuf[0] = aChar;
	abuf[1] = '\0';
	rbuf[0] = replaceChar;
	rbuf[1] = '\0';
	while([self index:aChar]!=NULL)
		[self replace:abuf with:rbuf];
	return self;
}

- ( char * ) nthField: ( int ) fieldNumber useAsDelimiter: ( char ) c
{
	char * field;
	// (fieldNumber+1) is needed cause it starts on field 1 not 0
	id fieldString = [ self extractPart:(fieldNumber+1) useAsDelimiter:c ];
	if(!fieldString)
		return NULL;
	field = NXZoneMalloc( [ self zone ], [ fieldString length ] + 1 );
	strcpy(field, [ fieldString stringValue ]);
	return field;
}

- ( char * ) nthField: ( int ) fieldNumber
{
	return [ self nthField:fieldNumber useAsDelimiter:' ' ];
}

- ( char * ) nthQuotedField: ( int ) fieldNumber
{
	return [ self nthField:fieldNumber*2+1 useAsDelimiter:'"' ];
}


- ( char * ) lastField
{
	char * field;
	id str = [ self extractPart:DAY_LAST useAsDelimiter:' ' ];
	field = NXZoneMalloc([self zone], [str length] + 1);
	strcpy(field, [str stringValue]);
	[str free];
	return field;
}

- ( char * ) firstField
{
	char * field;
	id str = [ self extractPart:DAY_FIRST useAsDelimiter:' ' ];
	field = NXZoneMalloc([self zone], [str length] + 1);
	strcpy(field, [str stringValue]);
	[str free];
	return field;
}

- ( int ) numberFields
{
	return [self numWords];
}

- addStrings: ( const char *) fields,  ...
{
	const char *aField;
	va_list ptr;

	va_start( ptr, fields );
	if(( [self stringValue] == NULL) && ( fields != NULL ))
	{
		[self setStringValue:fields];
		aField = va_arg( ptr, char * );
	}
	else
		aField = fields;
	while ( aField != NULL ){
		[self cat:aField];
		aField = va_arg( ptr, char * ); 
	}
	va_end( ptr );
	return self;
}

- addToEndOfString: ( const char *) aString
{
	[self cat:aString];
	return self;
}

- addToFrontOfString: ( const char *) aString
{
	[self insert:aString at:0];
	return self;
}

- addCharToEndOfString: ( char ) aChar
{
	char buf[ 2 ];
	buf[ 1 ] = '\0';
	buf[ 0 ] = aChar;
	[ self addToEndOfString: buf ];
	return self;
}

- addCharToFrontOfString: ( char ) aChar
{
	char buf[ 2 ];
	buf[ 1 ] = '\0';
	buf[ 0 ] = aChar;
	[ self addToFrontOfString: buf ];
	return self;
}

@end
